@@ -79,7 +79,7 @@ use URI ();
 use Scalar::Util qw/ blessed /;
 use Errno qw / :POSIX /;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 =head2 new($class, %opts)
 
@@ -100,7 +100,7 @@ Sets the port number of remote point.
 =item slots
 
 By default it's equal to 5.
-Sets the max amount slots.
+Sets the maximum amount of slots.
 These slot will be filled one by one if required.
 
 =item ssl
@@ -111,7 +111,7 @@ Sets the scheme of requests: HTTP or HTTPS.
 =item ssl_opts
 
 It's a HashRef with options to control SSL Layer.
-See the constructor arguments of C<IO::Socket::SSL> for details.
+See C<IO::Socket::SSL> constructor arguments for details.
 
 =item connect_timeout
 
@@ -338,7 +338,7 @@ sub _get_free_slot ($self) {
 
 =head2 add ($self, $request_or_uri, $timeout = undef)
 
-Adss HTTP request into empty slot.
+Adds HTTP request into empty slot.
 
 If the request was successfully added, then it will return 1.
 Otherwise it will return 0.
@@ -695,7 +695,7 @@ sub _get_response_from_ready_slot ($self) {
 Closes connections in slots in the following cases:
 
     1. The slot was marked as timeouted
-    2. C<inactivity_conn_ts> was set and the connection was expired
+    2. The "inactivity_conn_ts" was set and the connection was expired
     3. There are some errors in socket (for example: Connection reset by peer, Broken pipe, etc)
 
 =cut
